@@ -5,13 +5,13 @@
 #include "model.h"
 
 namespace cec {
-    class spherical : public model {
+    class spherical: public model {
     public:
         explicit spherical(int n)
                 : n(n),
                   ce_constant(std::log(2.0 * m::PI * m::E / n)) {}
 
-        double cross_entropy(const mat &cov) const noexcept override {
+        double cross_entropy(const covariance &cov) const noexcept override {
             double tr = trace(cov);
             return (ce_constant + std::log(tr)) * n / 2;
         }
